@@ -14,10 +14,10 @@ import shutil
 
 
 def _find_chrome(user_given_path=None):
-    """Find a Chrome executable.
+    """Finds a Chrome executable.
 
-    Search chrome on a given path.
-    If no path given, try to find chrome on a Windows or Unix system.
+    Search Chrome on a given path. If no path given,
+    try to find Chromeor Chromium-browser on a Windows or Unixsystem.
 
     Raises
     ------
@@ -116,6 +116,7 @@ class HtmlToImage():
         self.size = size
         self.temp_path = temp_path
 
+        # TODO : add @property + setter on self.browser to do the following
         if self.browser == "chrome":
             self._render = self._chrome_render
             self.chrome_path = chrome_path
@@ -234,7 +235,7 @@ class HtmlToImage():
         dest = os.path.join(self.temp_path, as_filename)
         shutil.copyfile(src, dest)
 
-    def screenshot(self, file, output_file='screenshot.png'):
+    def screenshot(self, file, output_file='screenshot.png', size=None):
         """Takes a screenshot of a _previously loaded_ file or string.
 
         Parameters
@@ -246,8 +247,15 @@ class HtmlToImage():
                 Name as which the screenshot will be saved.
                 File extension (e.g. .png) has to be included.
                 Default is screenshot.png
+
+            size: str, optional
+                Size of the screenshot that will be taken when the
+                method is called. Also changes the size for future screenshots.
         """
 
+        if size is not None:
+            self.size = size
+
         file = os.path.join(self.temp_path, file)
 
         if os.path.dirname(output_file) != '':
@@ -259,7 +267,7 @@ class HtmlToImage():
 
         self._render(output_file=output_file, input_file=file)
 
-    def screenshot_url(self, url, output_file='screenshot.png'):
+    def screenshot_url(self, url, output_file='screenshot.png', size=None):
         """Takes a screenshot of a given URL.
 
         The given URL should be well formed or it may result in undefined
@@ -277,8 +285,15 @@ class HtmlToImage():
                     Name as which the screenshot will be saved.
                     File extension (e.g. .png) has to be included.
                     Default is screenshot.png
+
+            size: str, optional
+                Size of the screenshot that will be taken when the
+                method is called. Also changes the size for future screenshots.
         """
 
+        if size is not None:
+            self.size = size
+
         if os.path.dirname(output_file) != '':
             raise ValueError(
                 "the output_file parameter should be a filename "
